==> zio-aws-connect_2.13-5.17.295.22-sources.jar: zio/aws/connect/model/VocabularyLanguageCode.scala <==
package zio.aws.connect.model
import scala.jdk.CollectionConverters._
sealed trait VocabularyLanguageCode {
  def unwrap
      : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode
}
object VocabularyLanguageCode {
  def wrap(
      value: software.amazon.awssdk.services.connect.model.VocabularyLanguageCode
  ): zio.aws.connect.model.VocabularyLanguageCode = value match {
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.AR_AE =>
      val r = `ar-AE`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_CH =>
      val r = `de-CH`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_DE =>
      val r = `de-DE`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AB =>
      val r = `en-AB`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AU =>
      val r = `en-AU`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_GB =>
      val r = `en-GB`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IE =>
      val r = `en-IE`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IN =>
      val r = `en-IN`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_US =>
      val r = `en-US`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_WL =>
      val r = `en-WL`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_ES =>
      val r = `es-ES`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_US =>
      val r = `es-US`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_CA =>
      val r = `fr-CA`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_FR =>
      val r = `fr-FR`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.HI_IN =>
      val r = `hi-IN`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.IT_IT =>
      val r = `it-IT`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.JA_JP =>
      val r = `ja-JP`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.KO_KR =>
      val r = `ko-KR`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_BR =>
      val r = `pt-BR`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_PT =>
      val r = `pt-PT`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ZH_CN =>
      val r = `zh-CN`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.UNKNOWN_TO_SDK_VERSION
  }
  case object `ar-AE` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.AR_AE
  }
  case object `de-CH` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_CH
  }
  case object `de-DE` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_DE
  }
  case object `en-AB` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AB
  }
  case object `en-AU` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AU
  }
  case object `en-GB` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_GB
  }
  case object `en-IE` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IE
  }
  case object `en-IN` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IN
  }
  case object `en-US` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_US
  }
  case object `en-WL` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_WL
  }
  case object `es-ES` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_ES
  }
  case object `es-US` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_US
  }
  case object `fr-CA` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_CA
  }
  case object `fr-FR` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_FR
  }
  case object `hi-IN` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.HI_IN
  }
  case object `it-IT` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.IT_IT
  }
  case object `ja-JP` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.JA_JP
  }
  case object `ko-KR` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.KO_KR
  }
  case object `pt-BR` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_BR
  }
  case object `pt-PT` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_PT
  }
  case object `zh-CN` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ZH_CN
  }
}

==> zio-aws-connect_2.13-6.20.149.2-sources.jar: zio/aws/connect/model/VocabularyLanguageCode.scala <==
package zio.aws.connect.model
import scala.jdk.CollectionConverters._
sealed trait VocabularyLanguageCode {
  def unwrap
      : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode
}
object VocabularyLanguageCode {
  def wrap(
      value: software.amazon.awssdk.services.connect.model.VocabularyLanguageCode
  ): zio.aws.connect.model.VocabularyLanguageCode = value match {
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.AR_AE =>
      val r = `ar-AE`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_CH =>
      val r = `de-CH`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_DE =>
      val r = `de-DE`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AB =>
      val r = `en-AB`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AU =>
      val r = `en-AU`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_GB =>
      val r = `en-GB`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IE =>
      val r = `en-IE`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IN =>
      val r = `en-IN`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_US =>
      val r = `en-US`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_WL =>
      val r = `en-WL`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_ES =>
      val r = `es-ES`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_US =>
      val r = `es-US`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_CA =>
      val r = `fr-CA`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_FR =>
      val r = `fr-FR`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.HI_IN =>
      val r = `hi-IN`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.IT_IT =>
      val r = `it-IT`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.JA_JP =>
      val r = `ja-JP`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.KO_KR =>
      val r = `ko-KR`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_BR =>
      val r = `pt-BR`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_PT =>
      val r = `pt-PT`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ZH_CN =>
      val r = `zh-CN`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_NZ =>
      val r = `en-NZ`
      r
    case software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_ZA =>
      val r = `en-ZA`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.UNKNOWN_TO_SDK_VERSION
  }
  case object `ar-AE` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.AR_AE
  }
  case object `de-CH` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_CH
  }
  case object `de-DE` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.DE_DE
  }
  case object `en-AB` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AB
  }
  case object `en-AU` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_AU
  }
  case object `en-GB` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_GB
  }
  case object `en-IE` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IE
  }
  case object `en-IN` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_IN
  }
  case object `en-US` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_US
  }
  case object `en-WL` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_WL
  }
  case object `es-ES` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_ES
  }
  case object `es-US` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ES_US
  }
  case object `fr-CA` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_CA
  }
  case object `fr-FR` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.FR_FR
  }
  case object `hi-IN` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.HI_IN
  }
  case object `it-IT` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.IT_IT
  }
  case object `ja-JP` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.JA_JP
  }
  case object `ko-KR` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.KO_KR
  }
  case object `pt-BR` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_BR
  }
  case object `pt-PT` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.PT_PT
  }
  case object `zh-CN` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.ZH_CN
  }
  case object `en-NZ` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_NZ
  }
  case object `en-ZA` extends zio.aws.connect.model.VocabularyLanguageCode {
    override def unwrap
        : software.amazon.awssdk.services.connect.model.VocabularyLanguageCode =
      software.amazon.awssdk.services.connect.model.VocabularyLanguageCode.EN_ZA
  }
}
